pub enum Filter<'a, S: AsRef<str>> {
None,
By(&'a [S]),
}Expand description
Filter based on Target as specified for various items.
Please note: This does only filter based on what is stored in the target field of an item
(e.g., ProgramRequest::targets) and should not get interpreted by the server.
Unfortunately, the specification is not very clear about this behavior, so some servers might interpret it differently. There has been some discussion with the authors of the standard in https://github.com/oadr3-org/openadr3-vtn-reference-implementation/issues/83 (sadly not public).
Variants
None
Do not apply any filtering
By(&'a [S])
Filter a list of Target.
It will be encoded to the request as query parameters,
e.g., /programs?targets=group-1&targets=group-2.
Implementations