pub struct PaginationOptions {
pub skip: usize,
pub limit: usize,
}Expand description
Allows setting specific skip and limit values for list queries.
In most cases, you should not need this functionality
but use the _list functions
that automatically try to iterate though all pages to retrieve all entities
Fields
skip: usizelimit: usizeAuto Trait Implementations
impl Freeze for PaginationOptions
impl RefUnwindSafe for PaginationOptions
impl Send for PaginationOptions
impl Sync for PaginationOptions
impl Unpin for PaginationOptions
impl UnsafeUnpin for PaginationOptions
impl UnwindSafe for PaginationOptions