pub struct ReportClient<K> { /* private fields */ }Expand description
Client to manage the data of a specific report
Can be created by a EventClient
let client = Client::<BusinessLogic>::with_url("https://your-vtn.com".try_into().unwrap(), None);
let event = client.get_event_by_id(&"event-1".parse().unwrap()).await.unwrap();
// retrieve all reports in that specific event, optionally filtered by the client name
let mut reports = event.get_report_list(Some("client-name")).await.unwrap();
let mut report = reports.remove(0);
// change report name
report.content_mut().report_name = Some("new-report-name".to_string());
report.update().await.unwrap()Implementations
Sourceimpl<K: ClientKind> ReportClient<K>
impl<K: ClientKind> ReportClient<K>
Sourcepub fn created_date_time(&self) -> &DateTime<Utc>
pub fn created_date_time(&self) -> &DateTime<Utc>
Get the time the report was created on the VTN
Sourcepub fn modification_date_time(&self) -> &DateTime<Utc>
pub fn modification_date_time(&self) -> &DateTime<Utc>
Get the time the report was last modified on the VTN
Sourcepub fn content(&self) -> &ReportRequest
pub fn content(&self) -> &ReportRequest
Read the data of the report
Sourcepub fn content_mut(&mut self) -> &mut ReportRequest
pub fn content_mut(&mut self) -> &mut ReportRequest
Modify the data of the report.
Make sure to call update
after your modifications to store them on the VTN