pub struct ResourceClient<K> { /* private fields */ }Expand description
A client for interacting with the data in a specific resource stored as a child element of a VEN on the VTN.
To retrieve or create a resource, refer to the VenClient.
Implementations
Sourceimpl<K: ClientKind> ResourceClient<K>
impl<K: ClientKind> ResourceClient<K>
Sourcepub fn id(&self) -> &ResourceId
pub fn id(&self) -> &ResourceId
Get the resource ID
Sourcepub fn created_date_time(&self) -> DateTime<Utc>
pub fn created_date_time(&self) -> DateTime<Utc>
Get the time the resource was created on the VTN
Sourcepub fn modification_date_time(&self) -> DateTime<Utc>
pub fn modification_date_time(&self) -> DateTime<Utc>
Get the time the resource was last updated on the VTN
Sourcepub fn content(&self) -> &BlResourceRequest
pub fn content(&self) -> &BlResourceRequest
Read the content of the resource
Sourcepub fn content_mut(&mut self) -> &mut BlResourceRequest
pub fn content_mut(&mut self) -> &mut BlResourceRequest
Modify the data of the resource.
Make sure to call update
after your modifications to store them on the VTN.